// RegenRadar.wdgt
// Author: bert@freudenbergs.de
// Copyright (c) Bert Freudenberg 2005-2014

var version = 15; // for update check

var region;
var period;
var size;

var currentExtent = {x: 0, y: 0};
var targetExtent = {x: 0, y: 0};


function makeKey(key)
{
    return widget.identifier + "-" + key;
}


function extent()
{
    var scale;
    switch (size)
    {
        case "small":
            scale = 0.5;
            break;
        case "medium":
            scale = 0.7;
            break;
        case "large":
            scale = 1.0;
            break;
        default:
            scale = 0.7;
    }
    var x = Math.max(document.getElementById("pictureLoader").width * scale, 200);
    var y = Math.max(document.getElementById("pictureLoader").height * scale, 200);
    return {x: x, y: y}
}


function setCurrentExtent(ext)
{	
    currentExtent = ext;
    if (window.widget)
        window.resizeTo(ext.x+32,ext.y+52);
    document.getElementById("picture").width = ext.x;
    document.getElementById("picture").height = ext.y;
    document.getElementById("c").width = ext.x;
    document.getElementById("c").height = ext.y;
}


function smoothResize()
{
    deltax = targetExtent.x - currentExtent.x; 
    deltay = targetExtent.y - currentExtent.y; 
    if (deltax != 0 || deltay != 0) {
        x = (Math.abs(deltax) < 2) ? targetExtent.x : Math.round(currentExtent.x + deltax / 2);
        y = (Math.abs(deltay) < 2) ? targetExtent.y : Math.round(currentExtent.y + deltay / 2);
        setCurrentExtent({x: x, y: y});
        setTimeout ("smoothResize();", 50);
    }
}


function imageLoaded()
{
    document.getElementById("picture").src = document.getElementById("pictureLoader").src;
    targetExtent = extent();
    smoothResize();
}

function showError()
{
    var img = "Images/error.png";
    document.getElementById("picture").src = img;
}

function showLoading(resetLoader)
{
    var img = "Images/loading.png";
    document.getElementById("picture").src = img;
	setCurrentExtent(extent());
    if (resetLoader) {
       document.getElementById("pictureLoader").onload = null;
       document.getElementById("pictureLoader").src = img;
    }
}

function expand(x)
{
	return ((x<10) ? "0" : "") + x
}

function loadImage()
{
    if (window.widget)
    {
        region = widget.preferenceForKey(makeKey("region"));
        period = widget.preferenceForKey(makeKey("period"));
        size = widget.preferenceForKey(makeKey("size"));
    }

    // region is upper-case starting in 1.5
    if (region && /[a-z]/.test(region)) region = null;
    
    if (!region) region = "DL";
    if (!period) period = "one";
    if (!size) size = "medium";

    var minutes = {std: 30, one: 60, two: 120, vie: 360}[period] || 60;
    var src = "http://www.wetteronline.de/?pid=p_radar_map&sid=Intensity&gid=" + region + "&iid=" + region + "&duration=" + minutes;

    document.getElementById("pictureLoader").onload = imageLoaded;
    document.getElementById("pictureLoader").onerror = showError;
    document.getElementById("pictureLoader").src = src;
}


function showBack()
{
    var front = document.getElementById("front");
    var back = document.getElementById("back");
	
    if (window.widget)
        widget.prepareForTransition("ToBack");
	
    front.style.display = "none";	
    back.style.display = "block";
						
    if (window.widget)
        setTimeout ("widget.performTransition();", 0);

    document.getElementById("iButtonHighlight").style.display = "none";
}

function showFront()
{
    var front = document.getElementById("front");
    var back = document.getElementById("back");	
			
    if (window.widget)
        widget.prepareForTransition("ToFront");
	
    front.style.display= "block";
    back.style.display= "none";
    showLoading(false);
    loadImage();
   
    if (window.widget)
        setTimeout ("widget.performTransition();", 0);
}


function changeRegion(elem)
{	
    region = elem.options[elem.selectedIndex].value;
    if (window.widget)
        widget.setPreferenceForKey(region,makeKey("region"));
} 


function changePeriod(elem)
{	
    period = elem.options[elem.selectedIndex].value;
    if (window.widget)
        widget.setPreferenceForKey(period,makeKey("period"));
} 


function changeSize(elem)
{	
    size = elem.options[elem.selectedIndex].value;
    if (window.widget)
        widget.setPreferenceForKey(size,makeKey("size"));
}

function updateCheck()
{
    var url = "http://freudenbergs.de/widgets/RegenRadar-Check-" + version + ".png",
        img = document.getElementById("updateImage");
        img.onerror = function() {
            img.onerror = null;
            img.src = "Images/checkfailed.png";
        };
        img.src = url;
}

function onLoad()
{
    createGenericButton(document.getElementById("doneButtonPlaceholder"), "Fertig", showFront);
    setCurrentExtent(extent());
    loadImage();
    if (region)
        document.getElementById("regionPopup").value = region;
    if (period)
        document.getElementById("periodPopup").value = period;
    if (size)
        document.getElementById("sizePopup").value = size;
    updateCheck();
}


function onRemove()
{
    widget.setPreferenceForKey(null,makeKey("region"));
    widget.setPreferenceForKey(null,makeKey("period"));
    widget.setPreferenceForKey(null,makeKey("size"));
}

function onHide()
{
    showLoading(true);
}

function onShow()
{
    loadImage();    
}

if (window.widget)
{
    widget.onremove = onRemove;
    widget.onhide = onHide;
    widget.onshow = onShow;
}